angular.module('beamng.apps')
.directive('classicDash', ['bngApi', 'StreamsManager', function (bngApi, StreamsManager) {
  return {
    template:
      '<object ng-style="myStyle" type="image/svg+xml" data="modules/apps/ClassicDash/classic-dash.svg"></object>',
    replace: true,
    link: function (scope, element, attrs) {

      var streams = ['electrics'];
    	StreamsManager.add(streams);
    	scope.$on('$destroy', function () {
        	StreamsManager.remove(streams);
    	});

      var preDarkMode = false;
      scope.background_svg = 'modules/apps/ClassicDash/classic-dash.svg';
      scope.myStyle = { 'background-color': 'rgba(255, 255, 255, 0.9)', 'width':'100%', 'height':'100%' };
      element.on('load', function () {
        var svg    = element[0].contentDocument
          , fuelbar = svg.getElementById('fuelbar')
          , fuel = svg.getElementById('fuel')
          , fuelFactor = svg.getElementById('fuelbar_border').getAttribute('height')
          , hbrake = { outer: svg.getElementById('hbrake_outer'),
                       inner: svg.getElementById('hbrake_inner')
                     }
          , lblink = svg.getElementById('blink_left')
          , rblink = svg.getElementById('blink_right')
          , abs = { outer: svg.getElementById('abs_outer'),
                    inner: svg.getElementById('abs_inner')
                  }
          , lights = svg.getElementById('lights')
        ;

        lblink.addEventListener('click', function () {
          bngApi.activeObjectLua('electrics.toggle_left_signal()');
        });

        rblink.addEventListener('click', function () {
          bngApi.activeObjectLua('electrics.toggle_right_signal()');
        });

        lights.addEventListener('click', function () {
          bngApi.activeObjectLua('electrics.toggle_lights()');
        });

        hbrake.outer.addEventListener('click', function () {
          bngApi.activeObjectLua('input.toggleEvent("parkingbrake")');
        });

        scope.$on('streamsUpdate', function (event, streams) {
          var isDarkMode = getDefaultValue("darkMode", 0) == 1;
          var themeDark = {
              background: 'rgba(0, 0, 0, 0.9)',
              text: 'rgba(255, 255, 255, 0.9)',
              border: 'rgb(160, 160, 160)',

              fuel: 'rgba(80, 80, 128, 0.7)',
              lowfuel: '#FF8000',

              pbrake: '#FF8000',
              blinker: 'rgba(0, 255, 0, 0.6)',

              beam_hi: '#398CB7',
              beam_lo: '#00FF00',

              empty: 'rgba(200, 200, 200, 0.9)',
          };
          var themeLight = {
              background: 'rgba(255, 255, 255, 0.9)',
              text: 'rgba(0, 0, 0, 0.9)',
              border: 'rgba(0, 0, 0, 0.9)',

              fuel: 'rgba(0,0,128,0.7)',
              lowfuel: '#FF8000',

              pbrake: '#FF8000',
              blinker: 'rgba(0, 255, 0, 0.6)',

              beam_hi: '#00f',
              beam_lo: 'rgba(0, 150, 0, 0.6)',

              empty: 'rgba(100, 100, 100, 0.9)',
          };
          var currentTheme = themeLight;
          if(isDarkMode) currentTheme = themeDark;
          scope.myStyle = { 'background-color': currentTheme.background, 'width':'100%', 'height':'100%' };
          if(preDarkMode != isDarkMode) {
            scope.$apply();
            preDarkMode = isDarkMode;
          }
          //console.log(scope.background_svg);
          // Fuel
          if (streams.electrics.lowfuel)
            fuelbar.style.fill=currentTheme.lowfuel;
          else
            fuelbar.style.fill=currentTheme.fuel;

          fuelbar.setAttribute('height', streams.electrics.fuel  * fuelFactor);

          fuel.style.fill = currentTheme.empty; 
          // Handbrake
          if (streams.electrics.parkingbrake > 0.5) {
            hbrake.outer.style.stroke = currentTheme.pbrake;
            hbrake.inner.style.fill = currentTheme.pbrake;
          } else {
            hbrake.outer.style.stroke = currentTheme.empty;
            hbrake.inner.style.fill = currentTheme.empty;
          }

          // Left Blinker
          if (streams.electrics.signal_L > 0.5)
            lblink.style.fill=currentTheme.blinker;
          else
            lblink.style.fill= currentTheme.empty;

          // Right Blinker
          if (streams.electrics.signal_R > 0.5)
            rblink.style.fill=currentTheme.blinker;
          else
            rblink.style.fill= currentTheme.empty;

          // ABS
          if (streams.electrics.abs > 0.5) {
            abs.inner.style.fill="#FF8000";
            abs.outer.style.stroke="#FF8000";
          } else {
            abs.inner.style.fill= currentTheme.empty;
            abs.outer.style.stroke= currentTheme.empty;
          }

          // Headlights
          if (streams.electrics.lights < 0.1)
            lights.style.fill = currentTheme.empty;
          else if (streams.electrics.lights < 1.1)
            lights.style.fill = currentTheme.beam_lo;
          else
            lights.style.fill = currentTheme.beam_hi;
        });
        
        function getDefaultValue(type, defVal) {
            return (localStorage.getItem("classicUI_" + type) || (defVal?1:0)) == 1;
        }
      });
    }
  };
}]);