
angular.module('beamng.apps')
.directive('classicEsc', ['StreamsManager', 'bngApi', function (StreamsManager, bngApi) {
  return {
    template: '<div style="cursor: pointer; overflow: hidden;"><canvas id="cEsc"></canvas></div>',
    replace: true,
    restrict: 'EA',
    link: function (scope, element, attrs) {
        
        var streams = ['electrics', 'escInfo'];
        StreamsManager.add(streams);
        scope.$on('$destroy', function () {
            StreamsManager.remove(streams);
        });

        var canvas = element.find("canvas")[0];
            
        var values = [];

        var gearType = "";
        var gearNames = ["P","R","N","D","2","1"];
        var gearNumStr, gearDirStr;


        document.getElementById("cEsc").addEventListener('click', function () {
            bngApi.activeObjectLua("if controller.getController('driveModes') then controller.getController('driveModes').nextDriveMode() else controller.getControllerSafe('esc').toggleESCMode() end");
        }, false);
        

        scope.$on('streamsUpdate', function (event, streams) {
            canvas.width = element[0].clientWidth;
            canvas.height = canvas.width / 1.4444;

            var isDarkMode = getDefaultValue("darkMode", 0) == 1;
            var themeDark = {
                background: 'rgba(0, 0, 0, 0.9)',
                text: 'rgba(220, 220, 220, 1)',
                border: 'rgb(160, 160, 160)',
            };
            var themeLight = {
                background: 'rgba(255, 255, 255, 0.9)',
                text: 'rgba(100, 100, 100, 1)',
                border: 'rgba(0, 0, 0, 0.9)',
            };
            var currentTheme = themeLight;
            if(isDarkMode) currentTheme = themeDark;
            var escActive = streams.electrics.escActive;
            var tcsActive = streams.electrics.tcsActive;

            var w = canvas.width;
            var h = canvas.height;
            var scale = w / 100;

            //console.log(scale);

            var ctx = canvas.getContext('2d');

            ctx.scale(scale, scale);
            ctx.clearRect(0, 0, w, h);
            ctx.fillStyle = currentTheme.background;
            ctx.fillRect(0, 0, w, h);

            if(streams.engineInfo) {
                if(streams.escInfo) {
                    ctx.textAlign="center";
                    ctx.font='18px Arial';
                    ctx.fillStyle = currentTheme.text;
                    if(escActive) {
                        ctx.fillStyle = "#FF8000";
                    }
                    ctx.fillText("ESC", 28, 22);

                    ctx.fillStyle = currentTheme.text;
                    if(tcsActive) {
                        ctx.fillStyle = "#FF8000";
                    }
                    ctx.fillText("TCS", 72, 22);

                    var clr = streams.escInfo.ledColor;
                    ctx.fillStyle = "#" + clr;
                    ctx.fillRect(0, 31, w, 4);
                } else {
                    ctx.textAlign="center";
                    ctx.font='18px Arial';
                    ctx.fillStyle = currentTheme.text;

                    ctx.fillText("No ESC", 50, 24);
                }

                //ctx.fillText("Gears (" + trans + ")", 50, 62);

            }

        });


        scope.$on('VehicleReset', function (_, data) {
        	scope.updateGearbox();
        });

        scope.$on('VehicleFocusChanged', function (_, data) {
        	scope.updateGearbox();
        });

        scope.updateGearbox = function() {
			try {
        		var exec = `powertrain.getDevice("gearbox")==null and "electric" or powertrain.getDevice("gearbox").type`;
	            bngApi.activeObjectLua(exec, function(data) {
					gearType = data;
	            });
	        } catch(e) {
	        	console.log("error");
	        }
        };
        
        scope.updateGearbox();

        function pad(num, size) {
            var s = num+"";
            while (s.length < size) s = "0" + s;
            return s;
        }
        function getDefaultValue(type, defVal) {
            return (localStorage.getItem("classicUI_" + type) || (defVal?1:0)) == 1;
        }
    }
  };
}]);
