
angular.module('beamng.apps')
.directive('classicPedals', ['StreamsManager', function (StreamsManager) {
  return {
    template: '<div style="overflow: hidden;"><canvas id="cPedals"></canvas></div>',
    replace: true,
    restrict: 'EA',
    link: function (scope, element, attrs) {
        StreamsManager.add(['electrics']);

        scope.$on('$destroy', function () {
            StreamsManager.remove(['electrics']);
        });

        var canvas = element.find("canvas")[0];
            
        var values = [];

        scope.$on('streamsUpdate', function (event, streams) {
            canvas.width = element[0].clientWidth;
            canvas.height = canvas.width / 1.4444;

            var isDarkMode = getDefaultValue("darkMode", 0) == 1;
            var themeDark = {
                background: 'rgba(0, 0, 0, 0.9)',
                text: 'rgba(255, 255, 255, 0.9)',
                border: 'rgb(160, 160, 160)',

                clutch: 'rgba(80, 80, 255, 0.5)',
                brake: 'rgba(255, 80, 80, 0.5)',
                throttle: 'rgba(80, 255, 80, 0.5)',
                pbrake: 'rgba(255, 255, 80, 0.5)',

            };
            var themeLight = {
                background: 'rgba(255, 255, 255, 0.9)',
                text: 'rgba(0, 0, 0, 0.9)',
                border: 'rgba(0, 0, 0, 0.9)',

                clutch: 'rgba(0, 0, 255, 0.5)',
                brake: 'rgba(255, 0, 0, 0.5)',
                throttle: 'rgba(0, 255, 0, 0.5)',
                pbrake: 'rgba(255, 255, 0, 0.5)',
            };
            var currentTheme = themeLight;
            if(isDarkMode) currentTheme = themeDark;

            var w = canvas.width;
            var h = canvas.height;
            var scale = w / 100;

            //console.log(scale);

            var ctx = canvas.getContext('2d');

            ctx.scale(scale, scale);
            ctx.clearRect(0, 0, w, h);
            ctx.fillStyle = currentTheme.background;
            ctx.fillRect(0, 0, w, h);
            if(streams.electrics) {
                var throttleVal = parseInt(streams.electrics.throttle * 100);
                var brakeVal = parseInt(streams.electrics.brake * 100);
                var clutchVal = Math.round(streams.electrics.clutch * 100 + 0.49);
                var parkingVal = parseInt(streams.electrics.parkingbrake * 100);

                //clutch
                ctx.fillStyle = currentTheme.clutch;
                ctx.fillRect(14,45,15,-clutchVal*0.4);

                //brake
                ctx.fillStyle = currentTheme.brake;
                ctx.fillRect(33,45,15,-brakeVal*0.4);

                //throttle
                ctx.fillStyle = currentTheme.throttle;
                ctx.fillRect(52,45,15,-throttleVal*0.4);

                //pbrake
                ctx.fillStyle = currentTheme.pbrake;
                ctx.fillRect(71,45,15,-parkingVal*0.4);


                //addtext
                ctx.font='7px Arial';
                ctx.textAlign="center";

                ctx.fillStyle = currentTheme.text;
                ctx.fillText(clutchVal,     21.5,52);
                ctx.fillText(brakeVal,      40.5,52);
                ctx.fillText(throttleVal,   59.5,52);
                ctx.fillText(parkingVal,    78.5,52);

                //add borders
                ctx.strokeStyle = currentTheme.border;
                ctx.strokeRect(52,45,15,-40);
                ctx.strokeRect(33,45,15,-40);
                ctx.strokeRect(14,45,15,-40);
                ctx.strokeRect(71,45,15,-40);

                ctx.fillStyle = currentTheme.text;
                ctx.textAlign="center";
                ctx.font='10px Arial';
                ctx.fillText("Pedals & Axis", 50, 62);
            }

        });

        function pad(num, size) {
            var s = num+"";
            while (s.length < size) s = "0" + s;
            return s;
        }
        function getDefaultValue(type, defVal) {
            return (localStorage.getItem("classicUI_" + type) || (defVal?1:0)) == 1;
        }
    }
  };
}]);
