
angular.module('beamng.apps')
.directive('classicTacho', ['StreamsManager', function (StreamsManager) {
  return {
    template: '<div style="overflow: hidden;"><canvas id="cTacho" height="90px"></canvas></div>',
    replace: true,
    restrict: 'EA',
    link: function (scope, element, attrs) {
        var streams = ['electrics', 'engineInfo'];
        StreamsManager.add(streams);
        scope.$on('$destroy', function () {
            StreamsManager.remove(streams);
        });

        var canvas = element.find("canvas")[0];
            
        var values = [];

        scope.$on('streamsUpdate', function (event, streams) {
            canvas.width = element[0].clientWidth;
            canvas.height = canvas.width * 3.3333;

            var isDarkMode = getDefaultValue("darkMode", 0) == 1;
            var themeDark = {
                background: 'rgba(0, 0, 0, 0.9)',
                text: 'rgba(255, 255, 255, 0.9)',
                border: 'rgb(160, 160, 160)',

                engIdle: 'rgba(80, 80, 255, 0.5)',
                engRedline: 'rgba(255, 80, 80, 0.5)',
                engNormal: 'rgba(80, 255, 80, 0.5)',
            };
            var themeLight = {
                background: 'rgba(255, 255, 255, 0.9)',
                text: 'rgba(0, 0, 0, 0.9)',
                border: 'rgba(0, 0, 0, 0.9)',

                engIdle: 'rgba(0, 0, 255, 0.5)',
                engRedline: 'rgba(255, 0, 0, 0.5)',
                engNormal: 'rgba(0, 255, 0, 0.5)',
            };
            var currentTheme = themeLight;
            if(isDarkMode) currentTheme = themeDark;
            
            var rpm = Math.round(Number(streams.engineInfo[4]));
            var rpmMax = streams.engineInfo[1];
            var rpmIdle = streams.engineInfo[0];
            
            var w = canvas.width;
            var h = canvas.height;
            var scale = w / 200;

            //console.log(scale);

            var ctx = canvas.getContext('2d');

            ctx.scale(scale, scale);
            ctx.clearRect(0, 0, w, h);
            ctx.fillStyle = currentTheme.background;
            ctx.fillRect(0, 0, w, h);
            var rgba = '';
            if(rpm < rpmIdle*1.25) {
                rgba = currentTheme.engIdle;
            } else if(rpm > rpmMax*0.9) {
                rgba = currentTheme.engRedline;
            } else {
                rgba = currentTheme.engNormal;
            }
            ctx.fillStyle = rgba;

            var fillAmount = Math.abs(rpm/(rpmMax/160));

            if(fillAmount > 160) fillAmount = 160;
            ctx.fillRect(20, 10, fillAmount, 25);

            ctx.font='20px Arial';
            ctx.textAlign="center";

            ctx.fillStyle = currentTheme.text;
            ctx.fillText(pad(Math.abs(rpm), 4),100,30);

            ctx.font='10px Arial';
            ctx.fillText("Engine RPM",100,62);

            ctx.font='10px Arial';
            ctx.fillText("0000",20,48);
            ctx.fillText(rpmMax,180,48);

            ctx.strokeStyle = currentTheme.border;
            ctx.lineWidth = 1;
            ctx.strokeRect(20,10,160,25);
        });

        function pad(num, size) {
            var s = num+"";
            while (s.length < size) s = "0" + s;
            return s;
        }

        function getDefaultValue(type, defVal) {
            return (localStorage.getItem("classicUI_" + type) || (defVal?1:0)) == 1;
        }

    }
  };
}]);
